## Installation

Add this line to your application's Gemfile:

```ruby
gem 'torgi_gov'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install torgi_gov_open_data

## Usage

### TorgiGov::ListNotificationForDate

get list notification for date publish or last change

params `publish_date_from`, `publish_date_to`, `last_change_from`, `last_change_to`

### Example

```
list_notification = TorgiGov::ListNotificationForDate.new(
  bid_kind: 1,                                      # type notification
  publish_date_from: DateTime.parse('01.01.2015'),  # from date 
  publish_date_to: DateTime.parse('10.01.2015')     # to date
)

list_notification.call
 => ["7887653", "7884807", "7881882", "7883295", "7887218", "7883328", ... , "7885169"]
```

### TorgiGov::BidKind1

load and parse notification type 1 (Rent, free use, trust management by property, other agreements providing for the transfer of rights of tenure in respect of state and municipal property)

```
TorgiGov::BidKind1.new(number: 7887653).call
 => {:number=>"090115/1987342/01", :organization=>{:type=>"\n        Орган власти местного самоуправления\n        1987342\n        АДМИНИСТРАЦИЯ МУНИЦИПАЛЬНОГО ОБРАЗОВАНИЯ СУХОРЕЧЕНСКИЙ СЕЛЬСОВЕТ БУЗУЛУКСКОГО РАЙОНА ОРЕНБУРГСКОЙ ОБЛАСТИ\n        \n        \n        5625006654\n        562501001\n        53212867000\n        14831561\n        75.11.32\n        1055603039755\n        461017, Оренбургская обл, Бузулукский р-н, с Сухоречка, ул Центральная, д. 4\n        +7 35342 6-32-19\n        +7 35342 6-32-19\n        Оренбургская область, Бузулукский район, с. Сухоречка, ул. Центральная, 4\n        \n    ", :id=>"Орган власти местного самоуправления", :fullName=>"АДМИНИСТРАЦИЯ МУНИЦИПАЛЬНОГО ОБРАЗОВАНИЯ СУХОРЕЧЕНСКИЙ СЕЛЬСОВЕТ БУЗУЛУКСКОГО РАЙОНА ОРЕНБУРГСКОЙ ОБЛАСТИ", :headOrg=>"", :inn=>"5625006654"}, :common=>{:bid_kind=>{:id=>"1", :name=>"Аренда, безвозмездное пользование, доверительное управление имуществом, иные договоры, предусматривающие передачу прав владения и пользования в отношении государственного и муниципального имущества"}, :bid_form=>{:id=>"1", :name=>"Открытый конкурс"}, :lotNum=>"2", :published=>"2015-01-09", :lastChanged=>"2015-06-04", :notificationUrl=>"http://torgi.gov.ru/restricted/notification/notificationView.html?notificationId=7887653", :bidAuctionDate=>"2015-02-13T11:00:00", :summationDate=>"2015-02-16"}, :docs=>[{:docType=>"Конкурсная документация", :created=>"2015-01-09", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=notification&id=7887677]]>"}, {:docType=>"Распорядительные документы", :created=>"2015-01-09", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=notification&id=7887670]]>"}], :lots=>[{:lotNum=>"1", :bidStatus=>"Несостоявшийся с единственным участником", :propertyType=>"Недвижимое имущество;Иное", :propKind=>"Муниципальная", :location=>"Оренбургская обл, Бузулукский р-н, Сухоречка с", :article=>"Ежемесячный платеж", :cancelDate=>"", :description=>"Система водоснабжения  на территории муниципального образования Сухореченский сельсовет Бузулукского района ( строение, сооружение, оборудование)", :mission=>"Водоснабжение на территории муниципального образования Сухореченский сельсовет Бузулукского района", :areaMeters=>"0.0", :termYear=>"0", :termMonth=>"11", :termDay=>"0", :monthPrice=>"3350.0", :yearPrice=>"", :dealFee=>"0.0", :contractFee=>"36850.0",:startPricePerMonth=>"", :depositSize=>"0.0", :isBurdened=>"0", :burdenDescription=>"", :isSubrent=>"0", :contractDate=>"", :contractPayment=>"", :contractPriceYear=>"", :contractPriceMonth=>"", :currency=>"рубли", :docs=>[{:description=>"", :created=>"", :docUrl=>""}, {:description=>"", :created=>"", :docUrl=>""}]}, {:lotNum=>"2", :bidStatus=>"Несостоявшийся с единственным участником", :propertyType=>"Недвижимое имущество;Иное", :propKind=>"Муниципальная", :location=>"Оренбургская обл, Бузулукский р-н, Сухоречка с", :article=>"Ежемесячный платеж", :cancelDate=>"", :description=>"система теплоснабжения на территории муниципального образования Сухореченский сельсовет Бузулукского района ( здание, сооружение, оборудование)", :mission=>"Теплоснабжение на территории муниципального образования Сухореченский сельсовет Бузулукского района", :areaMeters=>"0.0", :termYear=>"0", :termMonth=>"11", :termDay=>"0", :monthPrice=>"12870.0", :yearPrice=>"", :dealFee=>"0.0", :contractFee=>"141570.0", :startPricePerMonth=>"", :depositSize=>"0.0", :isBurdened=>"0", :burdenDescription=>"", :isSubrent=>"0", :contractDate=>"", :contractPayment=>"", :contractPriceYear=>"", :contractPriceMonth=>"", :currency=>"рубли", :docs=>[{:description=>"", :created=>"", :docUrl=>""}, {:description=>"", :created=>"", :docUrl=>""}]}]}
```

### TorgiGov::BidKind2

load and parse notification type 2 (Rental and sale of land)

```
TorgiGov::BidKind2.new(number: 7885169).call
 => {:number=>"050115/0411764/02", :organization=>{:type=>"\n        Орган власти субъекта РФ\n        411764\n        КОМИТЕТ ПО УПРАВЛЕНИЮ СОБСТВЕННОСТЬЮ МИНИСТЕРСТВА ЗЕМЕЛЬНЫХ И ИМУЩЕСТВЕННЫХ ОТНОШЕНИЙ РЕСПУБЛИКИ БАШКОРТОСТАН ПО КУШНАРЕНКОВСКОМУ РАЙОНУ\n        \n        \n        0234002797\n        023401001\n        80240835000\n        39983007\n        75.11.22\n        1020201384092\n      452230, Респ Башкортостан, Кушнаренковский р-н, с Кушнаренково, ул Садовая, д. 19\n        (34780) 5-76-79\n        (34780) 5-76-79\n        452230, Республика Башкортостан, Кушнаренковский район, село Кушнаренково, улица Садовая, д. 19\n        \n    ", :id=>"Орган власти субъекта РФ", :fullName=>"КОМИТЕТ ПО УПРАВЛЕНИЮ СОБСТВЕННОСТЬЮ МИНИСТЕРСТВА ЗЕМЕЛЬНЫХ И ИМУЩЕСТВЕННЫХ ОТНОШЕНИЙ РЕСПУБЛИКИ БАШКОРТОСТАН ПО КУШНАРЕНКОВСКОМУ РАЙОНУ", :headOrg=>"", :inn=>"0234002797"}, :common=>{:bid_kind=>{:id=>"2", :name=>"Аренда и продажа земельных участков"}, :bid_form=>{:id=>"2", :name=>"Открытый аукцион"}, :lotNum=>"18", :published=>"2015-01-07", :lastChanged=>"2015-06-02", :notificationUrl=>"http://torgi.gov.ru/restricted/notification/notificationView.html?notificationId=7885169", :bidAuctionDate=>"2015-02-11T11:00:00", :summationDate=>"2015-02-11"}, :docs=>[{:docType=>"Аукционная документация", :created=>"2015-01-07", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=notification&id=7886498]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]>"},{:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]>"}, {:docType=>"документ/контракт", :created=>"2015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}], :lots=>[{:lotNum=>"1", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:105", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Горная, 4", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Горная, 4", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаГалиуллин Рустем ФавилевичГалиуллин Рустем Фавилевич", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Галиуллин Рустем Фавилевич вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Галиуллин Рустем Фавилевич ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"2", :bidStatus=>"Несостоявшийся в связи с отсутствием допущенных участников", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:128", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Новая, 1", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Новая, 1", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся в связи с отсутствием допущенных участниковПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участка", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0",:depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"", :resultStartPriceAreaSm=>"0.0", :bidResults=>"Торги признаны несостоявшимися в связи с отсутствием заявок.", :winner=>" ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"3", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Неразграниченная", :cadastralNum=>"02:36:170503:182", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н,Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Новая, 19", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Новая, 19", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаНеразграниченнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаРамазанов Денис ФанисовичРамазанов Денис Фанисович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимисяв связи с поступлением одной заявки, единственный участник торгов Рамазанов Денис Фанисович вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Рамазанов Денис Фанисович ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"4", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:183", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Новая, 21", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Новая, 21", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаРамазанов Денис ФанисовичРамазанов Денис Фанисович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляютзадаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Рамазанов Денис Фанисович вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Рамазанов Денис Фанисович ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"5", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:119", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 2", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 2", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаГалиуллин Рустем ФавилевичГалиуллин Рустем Фавилевич", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Галиуллин Рустем Фавилевич вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона.", :winner=>"Галиуллин Рустем Фавилевич ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"},{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"6", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:115", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 11", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 11", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаГалиуллин Рустем ФавилевичГалиуллин Рустем ФавилевичШайхиев Тагир Ильдусович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Галиуллин Рустем Фавилевич вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона.", :winner=>"Галиуллин Рустем Фавилевич ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"",:created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"7", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:187", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 19", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 19", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаРамазанов Денис ФанисовичРамазанов Денис Фанисович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатахторгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Рамазанов Денис Фанисович вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Рамазанов Денис Фанисович ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"8", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:189", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 20", :unit=>"Квадратный метр", :area=>"1500.0",:description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 20", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаРамазанов Денис ФанисовичРамазанов Денис Фанисович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной ценылота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"",:isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Рамазанов Денис Фанисович вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Рамазанов Денис Фанисович ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"9", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:188", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 21", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 21",:termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаРамазанов Денис ФанисовичРамазанов Денис Фанисович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Рамазанов Денис Фанисович вправезаключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Рамазанов Денис Фанисович ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"10", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:185", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 22", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 22", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаРамазанов Денис ФанисовичРамазанов Денис Фанисович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащимобразом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"",:lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Рамазанов Денис Фанисович вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Рамазанов Денис Фанисович ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"11", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:184", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 23", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 23", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаРамазанов Денис ФанисовичРамазанов Денис Фанисович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Рамазанов Денис Фанисович вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Рамазанов Денис Фанисович ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]},{:lotNum=>"12", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:186", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 24", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Лесная, 24", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаРамазанов Денис ФанисовичРамазанов Денис Фанисович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Рамазанов Денис Фанисович вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Рамазанов Денис Фанисович ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"",:created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"13", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:170503:180", :mission=>"индивидуальное жилищное строительство", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Султанаево с", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Тукач, 10", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, с.Султанаево, ул.Тукач, 10", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Султанаево сКвадратный метрЦена земельного участкаШайхиева Лена ДамировнаШайхиева Лена Дамировна", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"250000.0", :startPriceAreaSm=>"166.67", :step=>"12500.0", :depositSize=>"50000.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"250000.0", :resultStartPriceAreaSm=>"166.66666666666666", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Шайхиева Лена Дамировна вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Шайхиева Лена Дамировна ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"14", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Неразграниченная", :cadastralNum=>"02:36:130201:9", :mission=>"Для ведения личного подсобного хозяйства", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Новогумерово д, Новая ул", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, д.Новогумерово, ул.Новая, д.63", :unit=>"Квадратный метр", :area=>"3329.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Старогумеровский, д.Новогумерово, ул.Новая, д.63", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаНеразграниченнаяБашкортостан Респ, Кушнаренковский р-н, Новогумерово д, Новая улКвадратный метрЦена земельного участкаХаматшина Гузелия ГабдулхайевнаХаматшина Гузелия Габдулхайевна", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"111000.0", :startPriceAreaSm=>"33.34", :step=>"5550.0", :depositSize=>"22200.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"27.01.2015 в 12-00", :articleVal=>"111000.0", :resultStartPriceAreaSm=>"33.34334635025533", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торговХаматшина Гузелия Габдулхайевна вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Хаматшина Гузелия Габдулхайевна ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"15", :bidStatus=>"Несостоявшийся в связи с отсутствием допущенных участников", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Муниципальная", :cadastralNum=>"02:36:120301:8", :mission=>"для размещения домов индивидуальной жилой застройки", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Расмекеево д, Пролетарская ул", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Расмекеевский, д.Расмекеево, ул.Пролетарская, д.14", :unit=>"Квадратный метр", :area=>"3516.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Расмекеевский, д.Расмекеево, ул.Пролетарская, д.14", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся в связи с отсутствием допущенных участниковПродажаМуниципальнаяБашкортостан Респ, Кушнаренковский р-н, Расмекеево д, Пролетарская улКвадратный метрЦена земельного участка", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"364000.0", :startPriceAreaSm=>"103.53", :step=>"18200.0", :depositSize=>"72800.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"1", :burdenDescription=>"на земельном участке расположен жилой дом площадью 53,8 кв.м", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015в 12-00", :articleVal=>"", :resultStartPriceAreaSm=>"0.0", :bidResults=>"Торги признаны несостоявшимися в связи с отсутствием заявок.", :winner=>" ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"16", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Неразграниченная", :cadastralNum=>"02:36:020101:63", :mission=>"Для ведения личного подсобного хозяйства", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Бакаево с, Речная ул", :location=>"Республика Башкортостан, Кушнаренковский район, сельсовет Бакаевский, д.Бакаево, ул.Речная, д.11", :unit=>"Квадратный метр", :area=>"2349.0", :description=>"Республика Башкортостан, Кушнаренковский район, сельсовет Бакаевский, д.Бакаево, ул.Речная, д.11", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаНеразграниченнаяБашкортостан Респ, Кушнаренковский р-н, Бакаево с, Речная улКвадратный метрЦена земельного участкаНурисламов Рустам РамилевичНурисламов Рустам Рамилевич", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"136000.0", :startPriceAreaSm=>"57.9", :step=>"6800.0", :depositSize=>"27200.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"136000.0", :resultStartPriceAreaSm=>"57.89697743720732", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Нурисламов Рустам Рамилевич вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Нурисламов Рустам Рамилевич ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"17", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Неразграниченная", :cadastralNum=>"02:36:180705:118", :mission=>"для индивидуального жилищного строительства", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Нижнеакбашево д, Полевая ул", :location=>"Республика Башкортостан, Кушнаренковский район, Шариповский сельсовет, д.Нижнеакбашево, ул.Полевая, д.7", :unit=>"Квадратный метр", :area=>"1500.0", :description=>"Республика Башкортостан, Кушнаренковский район, Шариповский сельсовет, д.Нижнеакбашево, ул.Полевая, д.7", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаНеразграниченнаяБашкортостан Респ, Кушнаренковский р-н, Нижнеакбашево д, Полевая улКвадратный метрЦена земельного участкаБатталов Марат ВильсуровичБатталов Марат Вильсурович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"188500.0", :startPriceAreaSm=>"125.67", :step=>"9425.0", :depositSize=>"37700.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"26.01.2015 в 12-00", :articleVal=>"188500.0", :resultStartPriceAreaSm=>"125.66666666666667", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Батталов Марат Вильсурович вправе заключить договор купли-продажи на земельный участок по начальной цене аукциона", :winner=>"Батталов Марат Вильсурович ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}, {:lotNum=>"18", :bidStatus=>"Несостоявшийся с единственным участником", :cancelDate=>"", :cancelReason=>"", :suspendDate=>"", :suspendReason=>"", :bidType=>"Продажа", :propKind=>"Неразграниченная", :cadastralNum=>"02:36:180201:150", :mission=>"Для индивидуального жилищного строительства", :kladrLocation=>"Башкортостан Респ, Кушнаренковский р-н, Воецское с, Центральная ул", :location=>"Республика Башкортостан, Кушнаренковский район, Шариповский сельсовет, с.Воецкое, ул Центральная, д 62А", :unit=>"Квадратный метр", :area=>"2630.0", :description=>"Республика Башкортостан, Кушнаренковский район, Шариповский сельсовет, с.Воецкое, ул Центральная, д 62А", :termYear=>"0", :termMonth=>"0", :article=>"Несостоявшийся с единственным участникомПродажаНеразграниченнаяБашкортостан Респ, Кушнаренковский р-н, Воецское с, Центральная улКвадратный метрЦена земельного участкаМкртчян Гор АраратовичМкртчян Гор Араратович", :pricePerMonth=>"", :pricePerYear=>"", :startPrice=>"166000.0", :startPriceAreaSm=>"63.12", :step=>"8300.0", :depositSize=>"33200.0", :depositDesc=>"Претенденты перечисляют задаток единым платежом в размере 20 % начальной цены лота на основании оформленного надлежащим образом договора о задатке на счет получателя, в срок не позднее 06.02.2015 года. Суммы задатков возвращаются участникам аукциона, за исключением его победителя, в течение трех банковских дней со дня подписания протокола о результатах торгов, по реквизитам, указанным в договоре о задатке", :maintenanceSize=>"", :buildConditions=>"", :techConditions=>"", :isBurdened=>"0", :burdenDescription=>"", :lotPhotosExist=>"0", :groundViewPlace=>"27.01.2015 в 12-00", :articleVal=>"166000.0", :resultStartPriceAreaSm=>"63.11787072243346", :bidResults=>"Торги признаны несостоявшимися в связи с поступлением одной заявки, единственный участник торгов Мкртчян Гор Араратович вправе заключить договор купли-продажи на земельныйучасток по начальной цене аукциона", :winner=>"Мкртчян Гор Араратович ", :currency=>"рубли", :currencyPercent=>"", :docs=>[{:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176810]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154869]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177220]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176844]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154894]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176847]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154911]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176899]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154930]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176922]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154933]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176952]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154960]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176960]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154977]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176998]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154998]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8176986]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155001]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177006]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154986]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177025]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8154995]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177037]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8155018]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177064]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151882]]>"}, {:description=>"", :created=>"2015-02-12", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177166]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177077]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151937]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177100]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151924]]>"}, {:description=>"", :created=>"2015-02-122015-02-10", :docUrl=>"<![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8177183]]><![CDATA[http://torgi.gov.ru/docview/fdcDocViewPage.html?section=lotContract&id=8151956]]>"}]}], :protocol=>[], :results=>[{:regNum=>"342", :name=>"Галиуллин Рустем Фавилевич", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"", :name=>"", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"314", :name=>"Рамазанов Денис Фанисович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"315", :name=>"Рамазанов Денис Фанисович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"341", :name=>"Галиуллин Рустем Фавилевич", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"344326", :name=>"Галиуллин Рустем ФавилевичШайхиев Тагир Ильдусович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"10", :refuseReason=>"претендент не допущен к участию в торгах в связи с тем,  что не внес необходимую для участия сумму задатка", :tenderPosition=>"", :offer=>""}, {:regNum=>"316", :name=>"Рамазанов Денис Фанисович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"317", :name=>"Рамазанов Денис Фанисович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"318", :name=>"Рамазанов Денис Фанисович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"319", :name=>"Рамазанов Денис Фанисович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"320", :name=>"Рамазанов Денис Фанисович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"321", :name=>"Рамазанов Денис Фанисович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"325", :name=>"Шайхиева Лена Дамировна", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"330", :name=>"Хаматшина Гузелия Габдулхайевна", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"", :name=>"", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"333", :name=>"Нурисламов Рустам Рамилевич", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"307", :name=>"Батталов Марат Вильсурович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}, {:regNum=>"327", :name=>"Мкртчян Гор Араратович", :inn=>"", :kpp=>"", :ogrn=>"", :location=>"", :phone=>"", :isSelected=>"1", :refuseReason=>"", :tenderPosition=>"", :offer=>""}]}
 ```

## Docs api 

https://torgi.gov.ru/opendata/recommendation.html